@@ -18,9 +18,17 @@ prior_PET  <- BayesTools::prior_PET
 #' @export
 prior_PEESE <- BayesTools::prior_PEESE
 
-
 #' @name prior_weightfunction
 #' @inherit BayesTools::prior_weightfunction
 #' @export
 prior_weightfunction <- BayesTools::prior_weightfunction
 
+#' @name prior_informed
+#' @inherit BayesTools::prior_informed
+#' @details Further details can be found in \insertCite{erp2017estimates;textual}{RoBMA},
+#' \insertCite{gronau2017bayesian;textual}{RoBMA}, and
+#' \insertCite{bartos2021bayesian;textual}{RoBMA}.
+#' @references
+#' \insertAllCited{}
+#' @export
+prior_informed <- BayesTools::prior_informed
