@@ -4,10 +4,10 @@
 #include <rng/RNG.h>
 #include <JRmath.h>
 
-using std::vector;
-using std::log;
-using std::exp;
-using std::fabs;
+
+
+
+
 
 
 // define parameters
@@ -26,18 +26,17 @@ namespace RoBMA {
 DWN2::DWN2() : VectorDist("dwnorm_2s", 4) {}
 
 
-bool DWN2::checkParameterLength(vector<unsigned int> const &len) const
+bool DWN2::checkParameterLength(std::vector<unsigned int> const &len) const
 {
   // there is one less cut-point then weights
   return n_crit_x(len) == n_omega(len) - 1;
 }
 
-bool DWN2::checkParameterValue(vector<double const *> const &par,
-			    vector<unsigned int> const &len) const
+bool DWN2::checkParameterValue(std::vector<double const *> const &par,
+			    std::vector<unsigned int> const &len) const
 {
   bool crit_x_OK = true;
   bool omega_OK  = true;
-  bool var_OK;
 
   // all crit_x must be non-negative
   for(unsigned i = 1; i < n_crit_x(len); ++i){
@@ -50,59 +49,54 @@ bool DWN2::checkParameterValue(vector<double const *> const &par,
   }
 
   // var is positive
-  var_OK = *par[1] > 0.0;
+  bool var_OK = *par[1] > 0.0;
 
   return crit_x_OK && omega_OK && var_OK;
 }
 
 double DWN2::logDensity(double const *x, unsigned int length, PDFType type,
-			  vector<double const *> const &par,
-			  vector<unsigned int> const &len,
+			  std::vector<double const *> const &par,
+			  std::vector<unsigned int> const &len,
 			  double const *lower, double const *upper) const
 {
 
-  double abs_x = fabs(*x);
+  double abs_x = std::fabs(*x);
   double mu    = *par[0];
   double var   = 1/ *par[1];
 
-  double w;
-  double nom;
   double denom = 0;
-  double denom_sum;
-  vector<double> denoms;
-  double log_lik;
-
-
+  double w = -68;
+  std::vector<double> denoms;
 
   // select weight to correspond to the current cut-off
   if(abs_x >= crit_x(par)[n_crit_x(len)-1]){
-    w = log(omega(par)[n_omega(len)-1]);
+    w = std::log(omega(par)[n_omega(len)-1]);
   }else if(abs_x < crit_x(par)[0]){
-    w = log(omega(par)[0]);
+    w = std::log(omega(par)[0]);
   }else{
     for(unsigned i = 1; i < n_omega(len); ++i){
       if( ( abs_x < crit_x(par)[i] ) && ( abs_x >= crit_x(par)[i-1]) ){
-        w = log(omega(par)[i]);
+        w = std::log(omega(par)[i]);
         break;
       }
     }
   }
 
   // compute the nominator
-  nom = dnorm(*x, mu, sqrt(var), true) + w;
+  double nom = dnorm(*x, mu, std::sqrt(var), true) + w;
 
   // compute the probabilities between cutpoints
   // the first one
-  denoms.push_back(pnorm(crit_x(par)[0], mu, sqrt(var), true, false) -  pnorm(-crit_x(par)[0], mu, sqrt(var), true, false));
+  denoms.push_back(pnorm(crit_x(par)[0], mu, std::sqrt(var), true, false) -  pnorm(-crit_x(par)[0], mu, std::sqrt(var), true, false));
   // check and correct for possibly negative numbers due to numerical imprecision
   if(denoms[0] < 0.0){
     denoms[0] = 0.0;
   }
-  denom_sum = denoms[0];
+  double denom_sum = denoms[0];
   // the ones in the middle
   if(n_omega(len) > 1){
     for(unsigned j = 1; j < n_omega(len) - 1; ++j){
-      denoms.push_back(pnorm(crit_x(par)[j], mu, sqrt(var), true, false) -  pnorm(-crit_x(par)[j], mu, sqrt(var), true, false) - denom_sum);
+      denoms.push_back(pnorm(crit_x(par)[j], mu, std::sqrt(var), true, false) -  pnorm(-crit_x(par)[j], mu, std::sqrt(var), true, false) - denom_sum);
       // check and correct for possibly negative numbers due to numerical imprecision
       if(denoms[j] < 0.0){
         denoms[j] = 0.0;
@@ -119,18 +113,18 @@ double DWN2::logDensity(double const *x, unsigned int length, PDFType type,
 
   // weight and sum the denominators
   for(unsigned k = 0; k < n_omega(len); ++k){
-    denom = denom + exp(log(denoms[k]) + log(omega(par)[k]));
+    denom = denom + std::exp(std::log(denoms[k]) + std::log(omega(par)[k]));
   }
 
   // compute the log likelihood
-  log_lik = nom-log(denom);
+  double log_lik = nom-std::log(denom);
 
   return log_lik;
 }
 
 void DWN2::randomSample(double *x, unsigned int length,
-			  vector<double const *> const &par,
-			  vector<unsigned int> const &len,
+			  std::vector<double const *> const &par,
+			  std::vector<unsigned int> const &len,
 			  double const *lower, double const *upper,
 			  RNG *rng) const
 {
@@ -138,8 +132,8 @@ void DWN2::randomSample(double *x, unsigned int length,
 }
 
 void DWN2::support(double *lower, double *upper, unsigned int length,
-	     vector<double const *> const &par,
-	     vector<unsigned int> const &len) const
+	     std::vector<double const *> const &par,
+	     std::vector<unsigned int> const &len) const
 {
   // no idea whether this is correct
   for (unsigned int i = 0; i < length; ++i) {
@@ -148,7 +142,7 @@ void DWN2::support(double *lower, double *upper, unsigned int length,
   }
 }
 
-unsigned int DWN2::length(vector<unsigned int> const &len) const
+unsigned int DWN2::length(std::vector<unsigned int> const &len) const
 {
   // no idea how this works
   return 1;
@@ -156,15 +150,15 @@ unsigned int DWN2::length(vector<unsigned int> const &len) const
 
 
 void DWN2::typicalValue(double *x, unsigned int length,
-			  vector<double const *> const &par,
-			  vector<unsigned int> const &len,
+			  std::vector<double const *> const &par,
+			  std::vector<unsigned int> const &len,
 			  double const *lower, double const *upper) const
 {
   // not implemented
 }
 
 
-bool DWN2::isSupportFixed(vector<bool> const &fixmask) const
+bool DWN2::isSupportFixed(std::vector<bool> const &fixmask) const
 {
   return true;
 }
